@@ -22,10 +22,11 @@
 #include "ui/resourcesdialogpage.h"
 #include "ui/sounddevicedialogpage.h"
 #include "ui/appearencedialogpage.h"
-#include "core/resourcemanager.h"
+#include "core/resourcerepository.h"
 #include "core/trainingsession.h"
 #include "core/editorsession.h"
 #include "core/resources/courseresource.h"
+#include "application.h"
 #include "models/languagemodel.h"
 #include "settings.h"
 #include "liblearnerprofile/src/profilemanager.h"
@@ -52,28 +53,18 @@ using namespace LearnerProfile;
 MainWindow::MainWindow()
     : m_actionCollection(new KActionCollection(this, QStringLiteral("artikulate")))
     , m_helpMenu(new KHelpMenu)
-    , m_resourceManager(new ResourceManager(this))
     , m_profileManager(new LearnerProfile::ProfileManager(this))
-    , m_trainingSession(new TrainingSession(this))
+    , m_trainingSession(new TrainingSession(m_profileManager, this))
 {
     rootContext()->setContextObject(new KLocalizedContext(this));
 
     // load saved sound settings
     OutputDeviceController::self().setVolume(Settings::audioOutputVolume());
 
-    // load resources
-    m_resourceManager->loadLanguageResources();
-    if (m_resourceManager->languageResources().count() == 0) {
-        qFatal("No language resources found, cannot start application.");
-    }
-    m_resourceManager->loadCourseResources();
-    m_trainingSession->setProfileManager(m_profileManager);
-
     // create menu
     setupActions();
 
     // set view
-    rootContext()->setContextProperty(QStringLiteral("g_resourceManager"), m_resourceManager);
     rootContext()->setContextProperty(QStringLiteral("g_trainingSession"), m_trainingSession);
     rootContext()->setContextProperty(QStringLiteral("g_profileManager"), m_profileManager);
     rootContext()->setContextProperty(QStringLiteral("kcfg_UseContributorResources"), Settings::useCourseRepository());
@@ -90,18 +81,16 @@ MainWindow::MainWindow()
         m_profileManager->addProfile(i18n("Unnamed Identity"));
     }
 
-    // connect to QML signals
-    connect(rootObjects().first(), SIGNAL(triggerDownloadCourses()),
-            this, SLOT(downloadNewStuff()));
-    connect(rootObjects().first(), SIGNAL(triggerSettingsDialog()),
-            this, SLOT(showSettingsDialog()));
-    connect(rootObjects().first(), SIGNAL(triggerAction(QString)),
+    // connect to QML signals;
+    connect(rootObjects().constFirst(), SIGNAL(ghnsCourseDataStatusChanged()),
+            this, SLOT(updateCourseResources()));
+    connect(rootObjects().constFirst(), SIGNAL(triggerAction(QString)),
             this, SLOT(triggerAction(QString)));
-    connect(rootObjects().first(), SIGNAL(switchMenuBarVisibility()),
+    connect(rootObjects().constFirst(), SIGNAL(switchMenuBarVisibility()),
             this, SLOT(switchMenuBarVisibility()));
 
     // set font for the phrase in trainer to default from kcfg file
-    QObject *phraseText = rootObjects().first()->findChild<QObject*>(QStringLiteral("phraseText"));
+    QObject *phraseText = rootObjects().constFirst()->findChild<QObject*>(QStringLiteral("phraseText"));
     if (phraseText) {
         phraseText->setProperty("font", Settings::trainingPhraseFont());
     }
@@ -114,11 +103,6 @@ MainWindow::~MainWindow()
     m_profileManager->sync();
 }
 
-ResourceManager * MainWindow::resourceManager() const
-{
-    return m_resourceManager;
-}
-
 KActionCollection * MainWindow::actionCollection()
 {
     return m_actionCollection;
@@ -131,11 +115,6 @@ void MainWindow::setupActions()
     actionCollection()->addAction(QStringLiteral("settings"), settingsAction);
     settingsAction->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
 
-    QAction *downloadsAction = new QAction(i18nc("@item:inmenu", "Download New Language Course"), this);
-    connect(downloadsAction, &QAction::triggered, this, &MainWindow::downloadNewStuff);
-    actionCollection()->addAction(QStringLiteral("download_new_stuff"), downloadsAction);
-    downloadsAction->setIcon(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")));
-
     QAction *configLearnerProfileAction = new QAction(i18nc("@item:inmenu", "Learner Profile"), this);
     connect(configLearnerProfileAction, &QAction::triggered, this, &MainWindow::configLearnerProfile);
     actionCollection()->addAction(QStringLiteral("config_learner_profile"), configLearnerProfileAction);
@@ -154,23 +133,20 @@ void MainWindow::showSettingsDialog()
     if (KConfigDialog::showDialog(QStringLiteral("settings"))) {
         return;
     }
-    QPointer<KConfigDialog> dialog = new KConfigDialog(0, QStringLiteral("settings"), Settings::self());
+    QPointer<KConfigDialog> dialog = new KConfigDialog(nullptr, QStringLiteral("settings"), Settings::self());
 
-    ResourcesDialogPage *resourceDialog = new ResourcesDialogPage(m_resourceManager);
     SoundDeviceDialogPage *soundDialog = new SoundDeviceDialogPage();
     AppearenceDialogPage *appearenceDialog = new AppearenceDialogPage();
 
-    resourceDialog->loadSettings();
+//    resourceDialog->loadSettings();
     soundDialog->loadSettings();
     appearenceDialog->loadSettings();
 
     dialog->addPage(soundDialog, i18nc("@item:inmenu", "Sound Devices"), QStringLiteral("audio-headset"), i18nc("@title:tab", "Sound Device Settings"), true);
     dialog->addPage(appearenceDialog, i18nc("@item:inmenu", "Fonts"), QStringLiteral("preferences-desktop-font"), i18nc("@title:tab", "Training Phrase Font"), true);
-    dialog->addPage(resourceDialog, i18nc("@item:inmenu", "Course Resources"), QStringLiteral("repository"), i18nc("@title:tab", "Resource Repository Settings"), true);
 
 //     connect(dialog, SIGNAL(settingsChanged(const QString&)), resourceDialog, SLOT(loadSettings()));
 //     connect(dialog, SIGNAL(settingsChanged(const QString&)), soundDialog, SLOT(loadSettings()));
-    connect(dialog.data(), &QDialog::accepted, resourceDialog, &ResourcesDialogPage::saveSettings);
     connect(dialog.data(), &QDialog::accepted, soundDialog, &SoundDeviceDialogPage::saveSettings);
     connect(dialog.data(), &QDialog::accepted, appearenceDialog, &AppearenceDialogPage::saveSettings);
     connect(dialog.data(), &QDialog::accepted, this, &MainWindow::updateTrainingPhraseFont);
@@ -181,14 +157,18 @@ void MainWindow::showSettingsDialog()
     dialog->exec();
 }
 
+void MainWindow::updateCourseResources()
+{
+    artikulateApp->resourceRepository()->reloadCourses();
+}
+
 void MainWindow::updateTrainingPhraseFont()
 {
-    QObject *phraseText = rootObjects().first()->findChild<QObject*>(QStringLiteral("phraseText"));
+    QObject *phraseText = rootObjects().constFirst()->findChild<QObject*>(QStringLiteral("phraseText"));
     if (!phraseText) {
         qCDebug(ARTIKULATE_LOG) << "no phraseText context object found, aborting";
         return;
     }
-    QFont f = phraseText->property("font").value<QFont>();
     phraseText->setProperty("font", Settings::trainingPhraseFont());
 }
 
@@ -197,50 +177,6 @@ void MainWindow::updateKcfgUseContributorResources()
     rootContext()->setContextProperty(QStringLiteral("kcfg_UseContributorResources"), Settings::useCourseRepository());
 }
 
-void MainWindow::downloadNewStuff()
-{
-    QPointer<KNS3::DownloadDialog> dialog = new KNS3::DownloadDialog(QStringLiteral("artikulate.knsrc"));
-    if (dialog->exec() == QDialog::Accepted) {
-        //update available courses
-        m_resourceManager->loadCourseResources();
-
-        if (!m_profileManager->activeProfile()) {
-            qCWarning(ARTIKULATE_LOG) << "Not registering course language for favorite languages:"
-                << "no active learner profile set";
-            delete dialog;
-            return;
-        }
-
-        // add languages of new courses to favorite languages
-        foreach (const KNS3::Entry &entry, dialog->changedEntries()) {
-            foreach (const QString &path, entry.installedFiles()) {
-                if (!path.endsWith(QLatin1String(".xml"))) {
-                    continue;
-                }
-                CourseResource *resource = new CourseResource(m_resourceManager, QUrl::fromLocalFile(path));
-                // set as active course if no training course is set
-                if (!m_trainingSession->course()) {
-                    m_trainingSession->setCourse(resource->course());
-                    m_trainingSession->setLanguage(resource->course()->language());
-                }
-                // update learning goals
-                //TODO will be gone after refactoring
-                foreach (LearningGoal *goal, m_profileManager->goals()) {
-                    if (goal->category() == LearningGoal::Language
-                        && goal->identifier() == resource->language()
-                    ) {
-                        // Learner::addGoal() checks for uniqueness of added goals
-                        m_profileManager->activeProfile()->addGoal(goal);
-                        break;
-                    }
-                }
-                resource->deleteLater();
-            }
-        }
-    }
-    delete dialog;
-}
-
 void MainWindow::configLearnerProfile()
 {
     qCritical() << "Not implemented"; //FIXME
